Changelog
---------

v0.2.0 (2013-04-02)
~~~~~~~~~~~~~~~~~~~

* Styled object's editing pages


v0.1.2 (2013-03-23)
~~~~~~~~~~~~~~~~~~~

* **Django 1.3 support dropped!** (there's too much differences between Django 1.3 and 1.4)
* installation process slightly changed (there's no need to copy or symlink base.html file for specific Django version)
* added WordPress look and feel for objects lists (change_list.html)
* CHANGELOG added


v0.1.1 (2013-03-19)
~~~~~~~~~~~~~~~~~~~

* installation scripts
* README and LICENSE files added


v0.1.0 (2013-03-19)
~~~~~~~~~~~~~~~~~~~

* top and left menu
